@@ -82,15 +82,18 @@ def CHECKIP(ipAddr):
     else:
         return False
 
-def SYSCOM(command, flag=1, ifreceived=None, debug=0):
+def SYSCOM(command, flag=True, ifreceived=None, debug=False):
+    def EXCEPTIONERROR():
+        TYPE('[syscom] Exception error')
+        TYPE(e)
+
     if flag == 1:
         ifreceived_status = -1
         try:
             (status, output) = subprocess.getstatusoutput(command)
         except Exception as e:
             if (debug):
-                TYPE('Exception error')
-                TYPE(e)
+                EXCEPTIONERROR()
 
         if status == 0:
             if (debug):
@@ -112,8 +115,7 @@ def SYSCOM(command, flag=1, ifreceived=None, debug=0):
             subprocess.Popen(['/bin/bash', '-c', command])
         except Exception as e:
             if (debug):
-                TYPE('Exception error')
-                TYPE(e)
+                EXCEPTIONERROR()
 
 def WRITERCSV(csvfile, inputlist):
     with open('%s' % csvfile, 'a+', newline='', encoding='utf-8-sig') as f:
